#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_LOGICAL_NOT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_LOGICAL_NOT_HPP_INCLUDED

#include <boost/simd/operator/include/functions/logical_not.hpp>

#endif
